/*
 *	PROTOS.H
 *	Tom Kerrigan's Simple Chess Program (TSCP)
 *
 *	Copyright 1997 Tom Kerrigan
 */


/* prototypes */

/* board.c */
void init_board();
void init_hash();
int hash_rand();
void set_hash();
BOOL in_check(int s);
BOOL attack(int sq, int s);
void gen();
void gen_caps();
void gen_push(int from, int to, int bits);
void gen_promote(int from, int to, int bits);
BOOL makemove(move_bytes m);
void takeback();

/* book.c */
void open_book();
void close_book();
int book_move();
BOOL book_match(char *s1, char *s2);

/* search.c */
void think(int output);
int search(int alpha, int beta, int depth);
int quiesce(int alpha, int beta);
int reps();
void sort_pv();
void sort(int from);
void checkup();

/* eval.c */
int eval();
int eval_light_pawn(int sq);
int eval_dark_pawn(int sq);
int eval_light_king(int sq);
int eval_lkp(int f);
int eval_dark_king(int sq);
int eval_dkp(int f);

/* main.c */
int get_ms();
int main();
int parse_move(char *s);
char *move_str(move_bytes m);
void print_board();
void xboard();
void print_result();
void bench();

#if UNDER_CE
    #include <stdarg.h>
    int __cdecl PrintF (const char *fmt, ...);
    int GetCh (void);
    typedef struct
    {
        int version;
        void *pIOInst;
        int (__stdcall *p_input_available) (void *pInst);
        char * (__stdcall *p_get_string) (void *pInst, char *s, int nmaxlen);
        void (__stdcall *p_put_string) (void *pInst, const char *s);
        int (__cdecl *p_print) (void *pInst, const char *fmt, ...);
        int (__cdecl *p_vprint) (void *pInst, const char *fmt, va_list args);
        unsigned int (__stdcall *p_available_memory) (void *pInst);
        void * (__stdcall *p_allocate_memory) (void *pInst, int nsize);
        void (__stdcall *p_free_memory) (void *pInst, void *pmem);
        int argc;
        char **argv;
    }
    TEngineIO;
    extern TEngineIO *EngineIO;
    #define malloc(n_) (EngineIO->p_allocate_memory(EngineIO->pIOInst,n_))
    #define free(p_) (EngineIO->p_free_memory(EngineIO->pIOInst,p_))
    #define printf PrintF
    #define puts(s_) printf("%s\n",s_)
    #define getch() GetCh()
    #define gets(s_) (EngineIO->p_get_string (EngineIO->pIOInst, s_, 255))
    #define fflush(f_)
    #define InputAvailable() (EngineIO->p_input_available(EngineIO->pIOInst))
#endif